# HMD Fusion Development Toolkit V3.0  

> AI Generated from ChatGPT processing the [Official PDF Document](./resources/HMD_Fusion_Development_Toolkit_-_V3_-_March_2025.pdf)

_March 2025_

## Introduction

Our ambition is for HMD Fusion to provide a platform for innovation for businesses, startups, communities, and people around the world — making new applications of smartphone technology more accessible and flexible for everyone.

HMD Fusion features next-generation design innovation, including built-in hardware connectors that enable endless new applications, known as "smart outfits."

Examples of smart outfits:
- A case with a cover that removes the constant interruption of digital notifications.
- A retail payment terminal to scan barcodes and accept payments.
- Many more ideas to create.

With HMD Fusion, we are introducing a radically new and innovative approach to smartphones and their capabilities.

> **Note:** This version includes final physical dimensions for HMD Fusion. It’s recommended to use a physical device to measure and test engineering/fabrication tolerances.

Join the community: [HMD Discord](https://bit.ly/hmddiscord)

---

## Design Specs

HMD Fusion is a streamlined computing core at its heart, creating space for endless new and innovative applications.

**3D Files:**  
We provide 3D source files of the HMD Fusion outline and an example smart outfit for use in your preferred 3D software.

- Download 3D files: [HMD Fusion APK Example 3D Files](https://downloads.ctfassets.net/wcfotm6rrl7u/aYYPsnBfWn8gKP5i2aqJT/c545b32631f5d97a700cff13dd82eaca/HMD_Fusion_APK_example_3D_files_V2-_September_2024.zip)

**Physical Dimensions:**
- Width: 75.5 mm
- Height: 164.15 mm
- Depth: 8.3 mm

---

## Interface

HMD Fusion includes six electrical connector pins arranged in a single horizontal row for hardware interfacing using smart "pogo pin" mechanisms.

- Pins #1–#5: USB 2.0 interface (data transfer).
- Pin #6: ADC (analog-to-digital converter) detection.

**USB 2.0 Interface:**
- Supports **USB host** and **accessory** modes.

---

## Hardware Details

**Power Specifications:**
- In "Charging Mode": Smart outfit provides up to **15W** to HMD Fusion.
- In "Power Mode": HMD Fusion provides up to **5W** to smart outfit.

**ADC Value Detection:**
- Eighteen (18) unique values can be communicated via the ADC pin.
- Example: Smart outfit triggers device behavior (like changing wallpaper).

**Download Demo APK:**  
[HMD Fusion ADC Demo APK](https://downloads.ctfassets.net/wcfotm6rrl7u/aYYPsnBfWn8gKP5i2aqJT/c545b32631f5d97a700cff13dd82eaca/HMD_Fusion_APK_example_3D_files_V2-_September_2024.zip)

**Sample Java Code (Read ADC Pin):**
```java
private static final String smart_avc = "cat /sys/bus/iio/devices/iio:device0/in_voltage_pm6450_smart_adc_therm_input";

String res = "";
try {
    Process process = Runtime.getRuntime().exec(smart_avc);
    process.waitFor();
    BufferedReader reader = new BufferedReader(new InputStreamReader(process.getInputStream()));
    String line;
    while ((line = reader.readLine()) != null) {
        res += line;
    }
} catch (Exception e) {
    e.printStackTrace();
}
try {
    String str = "Smart avc:" + res;
    smartAvc.setText(str);
} catch (IOException e) {
    e.printStackTrace();
}
```

---

## Power Management

**VBUS Power Management:**
- Controlled automatically based on screen status or via APIs.
- **Screen off:** VBUS power off after 10 minutes.
- **Screen on:** VBUS power on immediately.

**Manage VBUS Status (Java Example):**
```java
private void sendVbusControlIntent(boolean turnOn) {
    String action = turnOn ? ACTION_TURN_ON_VBUS : ACTION_TURN_OFF_VBUS;
    Intent intent = new Intent(action);
    intent.putExtra(EXTRA_FORCE_BYPASS, true);
    sendBroadcast(intent);
}
```
Check status:
```java
String status = Settings.Global.getString(this.getContentResolver(),"show_vbus_status");
```

---

## Android & USB 2.0 APIs

HMD Fusion will ship with Android 14.

**Supported modes:**
- **Host Mode:** HMD Fusion device acts as USB host.
- **Accessory Mode:** Smart outfit acts as USB device.

**Reference Links:**
- [Android USB Host and Accessory Overview](https://developer.android.com/reference/android/hardware/usb/package-summary)
- [AOA 2.0 Documentation](https://source.android.com/docs/core/interaction/accessories/aoa2)
- [Android USB Development](https://developer.android.com/develop/connectivity/usb)

---

## Have Questions?

**Join the HMD Discord Community:**  
[Join HMD Discord](https://bit.ly/hmddiscord)

**Business or Commercial Partnership Inquiry:**  
[Contact HMD Solutions](https://solutions.hmd.com/contact-us)

**Brand Collaboration Inquiry:**  
[Brand Collaboration Contact](https://www.hmd.com/en_int/collaborations-contact)

---

## Terms of Use  
_Effective March 3, 2025_

- **License:** Permitted use for designing smart outfits.
- **Restrictions:** No reverse engineering, sublicensing, or publishing code.
- **Termination:** Immediate if terms are breached.
- **Feedback:** HMD may freely use feedback without compensation.
- **Warranty:** Toolkit is provided "AS-IS."
- **Liability:** HMD is not liable for damages; limited liability where applicable.
- **Governing Law:** Finnish law, courts of Helsinki, Finland.

---

